@@ -113,10 +113,6 @@ def run():
         "--feedback",
         action="store_true",
     )
-    parser.add_argument(
-        "--zocalo_config_file",
-        help="Override location of Zocalo configuration file",
-    )
 
     verbosity = parser.add_mutually_exclusive_group()
     verbosity.add_argument(
@@ -133,13 +129,9 @@ def run():
         help="Increase logging output verbosity",
         default=0,
     )
-    args = parser.parse_args()
 
     # setup logging
-    if args.zocalo_config_file:
-        zc = zocalo.configuration.from_file(config_file=args.zocalo_config_file)
-    else:
-        zc = zocalo.configuration.from_file()
+    zc = zocalo.configuration.from_file()
     zc.activate()
 
     # Install a log filter to all existing handlers.
